@@ -1,42 +1,87 @@
-/*!!***************************************************************************
- *!! FILE NAME
- *!!	$Source: /var/cvs/pub/repository/LinCVS/src/getCvsMod.cpp,v $
- *!!
- *!! AUTHOR
- *!!	$Author: mishima $
- *!!
- *!! DATE, REVISION AND STATE
- *!!	$Date: 2001/11/02 01:03:26 $
- *!!	$Revision: 1.14 $
- *!!	$State: Exp $
- *!!
- *!! DESCRIPTION
- *!!
- *!!	Copyright (C) 2001 The LinCVS development team.
- *!!    Tilo Riemer <riemer@lincvs.org>
- *!!    Falk Brettschneider <gigafalk@yahoo.com>
- *!!    Wim Delvaux <wim.delvaux@chello.be>
- *!!    Jose Hernandez <joseh@tesco.net>
- *!!    Helmut Koll <HelmutKoll@web.de>
- *!!    Sven Trogisch <trogisch@iapp.de>
- *!!
- *!!	This program is free software; you can redistribute it and/or modify
- *!!	it under the terms of the GNU General Public License as published by
- *!!	the Free Software Foundation; either version 2, or (at your option)
- *!!	any later version.
- *!!
- *!!	This program is distributed in the hope that it will be useful,
- *!!	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *!!	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *!!	GNU General Public License for more details.
- *!!
- *!!**************************************************************************/
+/****************************************************************************
+**
+** $Id: getCvsMod.cpp,v 1.24 2004/01/11 22:11:45 riemer Exp $
+**
+** Copyright (C) 2001-2004 The LinCVS development team.
+**    Tilo Riemer <riemer@lincvs.org>
+**    Falk Brettschneider <gigafalk@yahoo.com>
+**    Frank Hemer <frank@hemer.org>
+**    Wim Delvaux <wim.delvaux@chello.be>
+**    Jose Hernandez <joseh@tesco.net>
+**    Helmut Koll <HelmutKoll@web.de>
+**    Tom Mishima <tmishima@mail.at-m.or.jp>
+**    Joerg Preiss <auba@auba.de>
+**    Sven Trogisch <trogisch@iapp.de>
+**
+**
+**----------------------------------------------------------------------------
+**
+**----------------------------------------------------------------------------
+**
+** LinCVS is available under two different licenses:
+**
+** If LinCVS is linked against the GPLed version of Qt 
+** LinCVS is released under the terms of GPL also.
+**
+** If LinCVS is linked against a nonGPLed version of Qt 
+** LinCVS is released under the terms of the 
+** LinCVS License for non-Unix platforms (LLNU)
+**
+**
+** LinCVS License for non-Unix platforms (LLNU):
+**
+** Redistribution and use in binary form, without modification, 
+** are permitted provided that the following conditions are met:
+**
+** 1. Redistributions in binary form must reproduce the above copyright
+**    notice, this list of conditions and the following disclaimer in the
+**    documentation and/or other materials provided with the distribution.
+** 2. It is not permitted to distribute the binary package under a name
+**    different than LinCVS.
+** 3. The name of the authors may not be used to endorse or promote
+**    products derived from this software without specific prior written
+**    permission.
+** 4. The source code is the creative property of the authors.
+**    Extensions and development under the terms of the Gnu Public License
+**    are limited to the Unix platform. Any distribution or compilation of 
+**    the source code against libraries licensed other than gpl requires 
+**    the written permission of the authors.
+**
+**
+** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
+** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
+** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
+** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
+** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
+** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
+** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
+** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
+** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
+** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
+** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+**
+**
+**
+** LinCVS License for Unix platforms:
+**
+** This program is free software; you can redistribute it and/or modify 
+** it under the terms of the GNU General Public License as published by 
+** the Free Software Foundation; either version 2 of the License, or 
+** (at your  option) any later version.  This program is distributed in 
+** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
+** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
+** PARTICULAR PURPOSE.
+**
+** See the GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software Foundation,
+** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+**
+*****************************************************************************/
 
 
 #include "config.h"
-#include "ac_system_defs.h"
-
-//#include <iostream.h>
 
 #include <qapplication.h>
 #include <qdir.h>
@@ -53,8 +98,9 @@
 #include <qhbox.h>
 #include <qlabel.h>
 
+#include "globals.h"
 #include "getCvsMod.h"
-#include "PixmapCache.h"
+#include "pixmapcache.h"
 
 /*****************************************************************************
  *  Definitions, Macros
@@ -207,7 +253,7 @@ void CvsRootDir::setOpen( bool o )
           QString sizeStr;
           QListViewItem *item = new QListViewItem( this, f->fileName(),  
                                                    (sizeStr=sizeStr.number(f->size())),
-                                                   (f->lastModified ()).toString());
+                                                   (f->lastModified ()).toString(LookAndFeel::g_dateTimeFormat));
           QString fname= item->text(0);
 
           if (f->isFile() && f->isReadable()) {
@@ -370,8 +416,12 @@ bool CvsRootDirView::ckReadable( QString& path, bool addExt )
     /*! should be a filename then, and must prior append the rcs extension */
     if (addExt) path.append(RcsExt);
     if (!(QFileInfo(path).isReadable())) {
-      QMessageBox::warning( this, "LinCVS - File Error",
-                            QString("Unable to read\n  ")+path+"\nCheck permissions" );
+      QString caption = "LinCVS - ";
+      caption +=  tr("File Error");
+      QString msg = tr("Unable to read");
+      msg += "\n%1\n";
+      msg += "Check permissions";
+      QMessageBox::warning( this, caption, msg.arg(path));
       return FALSE;
     }
   }
@@ -504,7 +554,7 @@ getCvsModule::getCvsModule( const QString& pathName,
 
   QHBox *hbox1 = new QHBox (box1);
   
-  QLabel *lb = new QLabel (tr("selected : "), hbox1);
+  new QLabel (tr("selected : "), hbox1);
   selLine = new QLineEdit(hbox1);
 
   QGroupBox *grp = new QButtonGroup( 1, QGroupBox::Vertical, box1 );
@@ -515,10 +565,10 @@ getCvsModule::getCvsModule( const QString& pathName,
   dummy = new QWidget (grp);
 
 /*! insert two pushbuttons at right  */
-  QPushButton *pbOk = new QPushButton(tr("&ok"), grp );
+  QPushButton *pbOk = new QPushButton(tr("&Ok"), grp );
   connect( pbOk, SIGNAL( clicked( ) ), SLOT( okButton() ) );
 
-  QPushButton *pbCancel = new QPushButton(tr("&cancel"), grp );
+  QPushButton *pbCancel = new QPushButton(tr("&Cancel"), grp );
   connect( pbCancel, SIGNAL( clicked( ) ), SLOT( cancelButton() ) );
 
 
@@ -527,7 +577,7 @@ getCvsModule::getCvsModule( const QString& pathName,
   connect (dirWin, SIGNAL (folderSelected( const QString & )), SLOT (okButton()));
 
   dirWin->addColumn(tr("Name"));
-  dirWin->addColumn(tr("Size     "));
+  dirWin->addColumn(tr("Size"));
   dirWin->addColumn(tr("Last Modified"));
   dirWin->setTreeStepSize( 20 );
 
